Documentation
¶
Index ¶
- Constants
- type CallCreateApplicationKey
- func (this CallCreateApplicationKey) CallIndex() uint8
- func (this CallCreateApplicationKey) CallName() string
- func (this *CallCreateApplicationKey) DecodeExtrinsic(tx *prim.DecodedExtrinsic) bool
- func (this CallCreateApplicationKey) PalletIndex() uint8
- func (this CallCreateApplicationKey) PalletName() string
- func (this *CallCreateApplicationKey) ToCall() prim.Call
- func (this *CallCreateApplicationKey) ToPayload() metadata.Payload
- type CallSubmitData
- func (this CallSubmitData) CallIndex() uint8
- func (this CallSubmitData) CallName() string
- func (this *CallSubmitData) DecodeExtrinsic(tx *prim.DecodedExtrinsic) bool
- func (this CallSubmitData) PalletIndex() uint8
- func (this CallSubmitData) PalletName() string
- func (this *CallSubmitData) ToCall() prim.Call
- func (this *CallSubmitData) ToPayload() metadata.Payload
- type EventApplicationKeyCreated
- type EventDataSubmitted
- type StorageAppKeys
- func (this *StorageAppKeys) Fetch(blockStorage interfaces.BlockStorageT, key StorageAppKeysKey) (prim.Option[StorageAppKeysEntry], error)
- func (this *StorageAppKeys) FetchAll(blockStorage interfaces.BlockStorageT) ([]StorageAppKeysEntry, error)
- func (this *StorageAppKeys) MapKeyHasher() uint8
- func (this *StorageAppKeys) PalletName() string
- func (this *StorageAppKeys) StorageName() string
- type StorageAppKeysEntry
- type StorageAppKeysKey
- type StorageNextAppId
Constants ¶
const PalletIndex = 29
const PalletName = "DataAvailability"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CallCreateApplicationKey ¶
type CallCreateApplicationKey struct {
Key []uint8
}
Do not add, remove or change any of the field members.
func (CallCreateApplicationKey) CallIndex ¶
func (this CallCreateApplicationKey) CallIndex() uint8
func (CallCreateApplicationKey) CallName ¶
func (this CallCreateApplicationKey) CallName() string
func (*CallCreateApplicationKey) DecodeExtrinsic ¶
func (this *CallCreateApplicationKey) DecodeExtrinsic(tx *prim.DecodedExtrinsic) bool
func (CallCreateApplicationKey) PalletIndex ¶
func (this CallCreateApplicationKey) PalletIndex() uint8
func (CallCreateApplicationKey) PalletName ¶
func (this CallCreateApplicationKey) PalletName() string
func (*CallCreateApplicationKey) ToCall ¶
func (this *CallCreateApplicationKey) ToCall() prim.Call
func (*CallCreateApplicationKey) ToPayload ¶
func (this *CallCreateApplicationKey) ToPayload() metadata.Payload
type CallSubmitData ¶
type CallSubmitData struct {
Data []uint8
}
Do not add, remove or change any of the field members.
func (CallSubmitData) CallIndex ¶
func (this CallSubmitData) CallIndex() uint8
func (CallSubmitData) CallName ¶
func (this CallSubmitData) CallName() string
func (*CallSubmitData) DecodeExtrinsic ¶
func (this *CallSubmitData) DecodeExtrinsic(tx *prim.DecodedExtrinsic) bool
func (CallSubmitData) PalletIndex ¶
func (this CallSubmitData) PalletIndex() uint8
func (CallSubmitData) PalletName ¶
func (this CallSubmitData) PalletName() string
func (*CallSubmitData) ToCall ¶
func (this *CallSubmitData) ToCall() prim.Call
func (*CallSubmitData) ToPayload ¶
func (this *CallSubmitData) ToPayload() metadata.Payload
type EventApplicationKeyCreated ¶
type EventApplicationKeyCreated struct {
Key []uint8
Owner metadata.AccountId
Id uint32 `scale:"compact"`
}
A new application key was created.
func (EventApplicationKeyCreated) EventIndex ¶
func (this EventApplicationKeyCreated) EventIndex() uint8
func (EventApplicationKeyCreated) EventName ¶
func (this EventApplicationKeyCreated) EventName() string
func (EventApplicationKeyCreated) PalletIndex ¶
func (this EventApplicationKeyCreated) PalletIndex() uint8
func (EventApplicationKeyCreated) PalletName ¶
func (this EventApplicationKeyCreated) PalletName() string
type EventDataSubmitted ¶
New Data was submitted.
func (EventDataSubmitted) EventIndex ¶
func (this EventDataSubmitted) EventIndex() uint8
func (EventDataSubmitted) EventName ¶
func (this EventDataSubmitted) EventName() string
func (EventDataSubmitted) PalletIndex ¶
func (this EventDataSubmitted) PalletIndex() uint8
func (EventDataSubmitted) PalletName ¶
func (this EventDataSubmitted) PalletName() string
type StorageAppKeys ¶
type StorageAppKeys struct {
Owner AccountId
AppId uint32 `scale:"compact"`
}
func (*StorageAppKeys) Fetch ¶
func (this *StorageAppKeys) Fetch(blockStorage interfaces.BlockStorageT, key StorageAppKeysKey) (prim.Option[StorageAppKeysEntry], error)
func (*StorageAppKeys) FetchAll ¶
func (this *StorageAppKeys) FetchAll(blockStorage interfaces.BlockStorageT) ([]StorageAppKeysEntry, error)
func (*StorageAppKeys) MapKeyHasher ¶
func (this *StorageAppKeys) MapKeyHasher() uint8
func (*StorageAppKeys) PalletName ¶
func (this *StorageAppKeys) PalletName() string
func (*StorageAppKeys) StorageName ¶
func (this *StorageAppKeys) StorageName() string
type StorageAppKeysEntry ¶
type StorageAppKeysEntry = StorageEntry[StorageAppKeysKey, StorageAppKeys]
type StorageAppKeysKey ¶
type StorageAppKeysKey = []byte
type StorageNextAppId ¶
type StorageNextAppId struct {
Value uint32 `scale:"compact"`
}
func (*StorageNextAppId) Fetch ¶
func (this *StorageNextAppId) Fetch(blockStorage interfaces.BlockStorageT) (uint32, error)
func (*StorageNextAppId) PalletName ¶
func (this *StorageNextAppId) PalletName() string
func (*StorageNextAppId) StorageName ¶
func (this *StorageNextAppId) StorageName() string
Click to show internal directories.
Click to hide internal directories.